@@ -4,6 +4,7 @@ import sys
 import json
 import glob
 import logging
+import inspect
 import argparse
 import traceback
 import unicodecsv
@@ -18,7 +19,7 @@ from billy.utils import configure_logging, term_for_session
 from billy.scrape.validator import DatetimeValidator
 
 
-def _clear_scraped_data(output_dir, scraper_type):
+def _clear_scraped_data(output_dir, scraper_type=''):
     # make or clear directory for this type
     path = os.path.join(output_dir, scraper_type)
     try:
@@ -42,16 +43,14 @@ def _get_configured_scraper(scraper_type, options, metadata):
         else:
             raise e
 
-    opts = {'output_dir': options.output_dir,
-            'strict_validation': options.strict,
-            'requests_per_minute': options.rpm,
-           }
-    if options.fastmode:
-        opts['requests_per_minute'] = 0
-        opts['cache_write_only'] = False
-    scraper = ScraperClass(metadata, **opts)
-    return scraper
+    return ScraperClass(metadata,
+                        output_dir=options.output_dir,
+                        strict_validation=options.strict,
+                        fastmode=options.fastmode)
 
+def _is_old_scrape(f):
+    argspec = inspect.getargspec(f)
+    return 'chamber' in argspec.args
 
 def _run_scraper(scraper_type, options, metadata):
     """
@@ -87,8 +86,12 @@ def _run_scraper(scraper_type, options, metadata):
 
     # run scraper against year/session/term
     for time in times:
-        for chamber in options.chambers:
-            scraper.scrape(chamber, time)
+        # old style
+        if _is_old_scrape(scraper.scrape):
+            for chamber in options.chambers:
+                scraper.scrape(chamber, time)
+        else:
+            scraper.scrape(time, chambers=options.chambers)
 
         if scraper_type == 'events' and len(options.chambers) == 2:
             scraper.scrape('other', time)
@@ -137,7 +140,8 @@ def _do_imports(abbrev, args):
             dist['num_seats'] = int(dist['num_seats'])
             db.districts.save(dist, safe=True)
     else:
-        print "%s not found, continuing without districts" % dist_filename
+        logging.getLogger('billy').warning("%s not found, continuing without "
+                                           "districts" % dist_filename)
 
     report = {}
 
@@ -146,8 +150,7 @@ def _do_imports(abbrev, args):
                 import_legislators(abbrev, settings.BILLY_DATA_DIR)
 
     if 'bills' in args.types:
-        report['bills'] = import_bills(abbrev, settings.BILLY_DATA_DIR,
-                                       args.oyster)
+        report['bills'] = import_bills(abbrev, settings.BILLY_DATA_DIR)
 
     if 'committees' in args.types:
         report['committees'] = \
@@ -198,37 +201,36 @@ def main(old_scrape_compat=False):
                           help='session(s) to scrape')
         what.add_argument('-t', '--term', action='append', dest='terms',
                             help='term(s) to scrape', default=[])
+
         for arg in ('upper', 'lower'):
             what.add_argument('--' + arg, action='append_const',
                               dest='chambers', const=arg)
         for arg in ('bills', 'legislators', 'committees', 'votes', 'events'):
             what.add_argument('--' + arg, action='append_const', dest='types',
                               const=arg)
-        scrape.add_argument('--nonstrict', action='store_false', dest='strict',
-                            default=True, help="don't fail immediately when"
-                            " encountering validation warning")
-        scrape.add_argument('--oyster', action='store_true', dest='oyster',
-                            default=False, help="push documents to oyster"
-                            " document tracking daemon")
-        scrape.add_argument('--fastmode', help="scrape in fast mode",
-                            action="store_true", default=False)
-        scrape.add_argument('-r', '--rpm', action='store', type=int,
-                            dest='rpm', default=60)
-        scrape.add_argument('--timeout', action='store', type=int,
-                            dest='SCRAPELIB_TIMEOUT', default=10)
-        scrape.add_argument('--retries', type=int,
-                            dest='SCRAPELIB_RETRY_ATTEMPTS')
-        scrape.add_argument('--retry_wait', type=int,
-                            dest='SCRAPELIB_RETRY_WAIT_SECONDS')
-        # actions
         for arg in ('scrape', 'import', 'report'):
             parser.add_argument('--' + arg, dest='actions',
                                 action="append_const", const=arg,
                                 help='only run %s step' % arg)
 
-        args = parser.parse_args()
+        # special modes for debugging
+        scrape.add_argument('--nonstrict', action='store_false', dest='strict',
+                            default=True, help="don't fail immediately when"
+                            " encountering validation warning")
+        scrape.add_argument('--fastmode', help="scrape in fast mode",
+                            action="store_true", default=False)
 
-        settings.update(args)
+        # scrapelib overrides
+        scrape.add_argument('-r', '--rpm', action='store', type=int,
+                            dest='SCRAPELIB_RPM')
+        scrape.add_argument('--timeout', action='store', type=int,
+                            dest='SCRAPELIB_TIMEOUT')
+        scrape.add_argument('--retries', type=int,
+                            dest='SCRAPELIB_RETRY_ATTEMPTS')
+        scrape.add_argument('--retry_wait', type=int,
+                            dest='SCRAPELIB_RETRY_WAIT_SECONDS')
+
+        args = parser.parse_args()
 
         # inject scraper paths so scraper module can be found
         for newpath in settings.SCRAPER_PATHS:
@@ -237,22 +239,23 @@ def main(old_scrape_compat=False):
         # get metadata
         module = __import__(args.module)
         metadata = module.metadata
+        module_settings = getattr(module, 'settings', {})
         abbrev = metadata['abbreviation']
 
+        # load state settings, then command line settings
+        settings.update(module_settings)
+        settings.update(args)
+
         configure_logging(args.module)
 
         # configure oyster
-        if args.oyster:
+        if settings.ENABLE_OYSTER:
             from oyster.conf import settings as oyster_settings
             oyster_settings.DOCUMENT_CLASSES[args.module + ':billtext'] = module.document_class
 
         # make output dir
         args.output_dir = os.path.join(settings.BILLY_DATA_DIR, abbrev)
-        try:
-            os.makedirs(args.output_dir)
-        except OSError as e:
-            if e.errno != 17:
-                raise e
+        _clear_scraped_data(args.output_dir)
 
         # if terms aren't set, use latest
         if not args.terms:
@@ -288,7 +291,9 @@ def main(old_scrape_compat=False):
 
         if not args.types:
             args.types = ['bills', 'legislators', 'votes', 'committees',
-                          'events', 'alldata']
+                          'alldata']
+            if 'events' in metadata['feature_flags']:
+                args.types.append('events')
 
         plan = """billy-update abbr=%s
     actions=%s
@@ -333,8 +338,10 @@ def main(old_scrape_compat=False):
             lex = None
             exc_traceback = None
 
-            # run scrapers
+            # start to run scrapers
             exec_start = dt.datetime.utcnow()
+
+            # scraper order matters
             order = ('legislators', 'committees', 'votes', 'bills', 'events')
             try:
                 for stype in order:
@@ -383,7 +390,6 @@ def main(old_scrape_compat=False):
 
         # imports
         if 'import' in args.actions:
-            print 'doing import'
             import_report = _do_imports(abbrev, args)
             scrape_data['imported'] = import_report
             # We're tying the run-logging into the import stage - since import
