@@ -6,12 +6,13 @@ import json
 import logging
 from collections import defaultdict
 
-from billy.utils import metadata, keywordize, term_for_session
+from billy.conf import settings
+from billy.utils import metadata, term_for_session
 from billy import db
 from billy.importers.names import get_legislator_id
 from billy.importers.subjects import SubjectCategorizer
 from billy.importers.utils import (insert_with_id, update, prepare_obj,
-                                   next_big_id, oysterize)
+                                   next_big_id, oysterize, fix_bill_id)
 
 import pymongo
 
@@ -19,24 +20,17 @@ logger = logging.getLogger('billy')
 
 
 def ensure_indexes():
+    # accomodates basic search / unique constraint
     db.bills.ensure_index([('state', pymongo.ASCENDING),
                            ('session', pymongo.ASCENDING),
                            ('chamber', pymongo.ASCENDING),
                            ('bill_id', pymongo.ASCENDING)],
                           unique=True)
-    db.bills.ensure_index([('state', pymongo.ASCENDING),
-                           ('_current_term', pymongo.ASCENDING),
-                           ('_current_session', pymongo.ASCENDING),
-                           ('chamber', pymongo.ASCENDING),
-                           ('_keywords', pymongo.ASCENDING)])
-    db.bills.ensure_index([('state', pymongo.ASCENDING),
-                           ('session', pymongo.ASCENDING),
-                           ('chamber', pymongo.ASCENDING),
-                           ('_keywords', pymongo.ASCENDING)])
-    db.bills.ensure_index([('state', pymongo.ASCENDING),
-                           ('session', pymongo.ASCENDING),
-                           ('chamber', pymongo.ASCENDING),
-                           ('type', pymongo.ASCENDING)])
+    # used for search in conjunction with ElasticSearch
+    db.bills.ensure_index([('versions.doc_id', pymongo.ASCENDING),
+                           ('created_at', pymongo.DESCENDING)])
+    # TODO: add a _current_term, _current_session index
+    # TODO: re-evaluate if the below indices are needed
     db.bills.ensure_index([('state', pymongo.ASCENDING),
                            ('session', pymongo.ASCENDING),
                            ('chamber', pymongo.ASCENDING),
@@ -67,16 +61,20 @@ def import_votes(data_dir):
 
 def oysterize_version(bill, version):
     titles = [bill['title']] + bill.get('alternate_titles', [])
+    logger.info('{0} tracked in oyster'.format(version['doc_id']))
     oysterize(version['url'], bill['state'] + ':billtext',
               id=version['doc_id'],
               # metadata
+              mimetype=version.get('mimetype', None),
+              titles=titles,
               state=bill['state'], session=bill['session'],
               chamber=bill['chamber'], bill_id=bill['bill_id'],
-              title=' , '.join(titles),
+              subjects=bill.get('subjects', []),
+              sponsors=[s['leg_id'] for s in bill['sponsors']],
              )
 
 
-def import_bill(data, votes, categorizer, oyster_documents=False):
+def import_bill(data, votes, categorizer):
     level = data['level']
     abbr = data[level]
 
@@ -158,7 +156,7 @@ def import_bill(data, votes, categorizer, oyster_documents=False):
 
     for version in data['versions']:
         # push versions to oyster
-        if oyster_documents and 'url' in version:
+        if settings.ENABLE_OYSTER and 'url' in version:
             oysterize_version(data, version)
 
         # Merge any version titles into the alternate_titles list
@@ -174,9 +172,6 @@ def import_bill(data, votes, categorizer, oyster_documents=False):
         pass
     data['alternate_titles'] = list(alt_titles)
 
-    # update keywords
-    data['_keywords'] = list(bill_keywords(data))
-
     if not bill:
         insert_with_id(data)
         return "insert"
@@ -185,7 +180,7 @@ def import_bill(data, votes, categorizer, oyster_documents=False):
         return "update"
 
 
-def import_bills(abbr, data_dir, oyster_documents=False):
+def import_bills(abbr, data_dir):
     data_dir = os.path.join(data_dir, abbr)
     pattern = os.path.join(data_dir, 'bills', '*.json')
 
@@ -208,7 +203,7 @@ def import_bills(abbr, data_dir, oyster_documents=False):
             data = prepare_obj(json.load(f))
 
         counts["total"] += 1
-        ret = import_bill(data, votes, categorizer, oyster_documents)
+        ret = import_bill(data, votes, categorizer)
         counts[ret] += 1
 
     logger.info('imported %s bill files' % len(paths))
@@ -225,26 +220,6 @@ def import_bills(abbr, data_dir, oyster_documents=False):
 
     return counts
 
-# fixing bill ids
-_bill_id_re = re.compile(r'([A-Z]*)\s*0*([-\d]+)')
-
-
-def fix_bill_id(bill_id):
-    bill_id = bill_id.replace('.', '')
-    return _bill_id_re.sub(r'\1 \2', bill_id).strip()
-
-
-def bill_keywords(bill):
-    """
-    Get the keyword set for all of a bill's titles.
-    """
-    keywords = keywordize(bill['title'])
-    keywords = keywords.union(keywordize(bill['bill_id']))
-    for title in bill['alternate_titles']:
-        keywords = keywords.union(keywordize(title))
-    return keywords
-
-
 def populate_current_fields(level, abbr):
     """
     Set/update _current_term and _current_session fields on all bills
