@@ -8,13 +8,15 @@ import pymongo
 import decimal
 import functools
 import unicodecsv
+import urlparse
 from operator import itemgetter
 from itertools import chain, imap
 from collections import defaultdict, OrderedDict
 
-from pymongo.objectid import ObjectId
+from bson.objectid import ObjectId
 
 from django.http import Http404, HttpResponse
+from django.core import urlresolvers
 from django.template.loader import render_to_string
 from django.views.decorators.cache import never_cache
 from django.shortcuts import render
@@ -82,6 +84,7 @@ def overview(request, abbr):
     context = {}
     context['metadata'] = meta
     context['report'] = report
+    context['sessions'] = db.bills.find({'state': abbr}).distinct('session')
 
     try:
         runlog = db.billy_runs.find({
@@ -103,6 +106,7 @@ or check out the scrape run report page for this state.
 
     return render(request, 'billy/state_index.html', context)
 
+
 def metadata_json(request, abbr):
     re_attr = re.compile(r'^    "(.{1,100})":', re.M)
     obj = metadata(abbr)
@@ -117,7 +121,7 @@ def metadata_json(request, abbr):
     tmpl = '<a href="{0}">{0}</a>'
     obj_json = re.sub('"(http://.+?)"',
                       lambda m: tmpl.format(*m.groups()), obj_json)
-    context = {'metadata': obj, 
+    context = {'metadata': obj,
                'keys': sorted(obj),
                'metadata_json': obj_json}
     return render(request, 'billy/metadata_json.html', context)
@@ -335,19 +339,17 @@ def bills(request, abbr):
     def decimal_format(value, TWOPLACES=decimal.Decimal(100) ** -1):
         '''Format a float like 2.2345123 as a decimal like 2.23'''
         n = decimal.Decimal(str(value))
-        n = n.quantize(TWOPLACES)#, context=Context(traps=[Inexact]))
+        n = n.quantize(TWOPLACES)
         return unicode(n)
 
-    # ------------------------------------------------------------------------
-    # Define data for the tables for counts, types, etc. 
+    # Define data for the tables for counts, types, etc.
     tablespecs = [
-        ('Bill Counts', {'rownames': [
-                                 'upper_count','lower_count',
-                                 'version_count']}),
+        ('Bill Counts', {'rownames': ['upper_count', 'lower_count',
+                                      'version_count']}),
 
         ('Bill Types', {
-            'keypath': ['bill_types'],       
-            'summary': {
+            'keypath': ['bill_types'],
+                'summary': {
                 'object_type': 'bills',
                 'key': 'type',
                 },
@@ -372,9 +374,9 @@ def bills(request, abbr):
                                  'sourceless_count', 'sponsorless_count',
                                  'actionless_count', 'actions_unsorted',
                                  'bad_vote_counts', 'version_count',
-                                 'versionless_count', 
+                                 'versionless_count',
 
-                                 'sponsors_with_leg_id', 
+                                 'sponsors_with_leg_id',
                                  'rollcalls_with_leg_id',
                                  'have_subjects',
                                  'updated_this_year',
@@ -384,7 +386,7 @@ def bills(request, abbr):
         ]
 
     format_as_percent = [
-        'sponsors_with_leg_id', 
+        'sponsors_with_leg_id',
         'rollcalls_with_leg_id',
         'have_subjects',
         'updated_this_year',
@@ -417,15 +419,15 @@ def bills(request, abbr):
         except KeyError:
             rownames = reduce(lambda x, y: set(x) | set(y), contexts)
 
-        for context in contexts:        
+        for context in contexts:
             for r in rownames:
 
                 val = context.get(r, 0)
                 if not isinstance(val, (int, float, decimal.Decimal)):
-                    val = len(val)    
+                    val = len(val)
 
                 use_percent = any([
-                    r in format_as_percent, 
+                    r in format_as_percent,
                     name in ['Actions by Actor', 'Actions by Type'],
                     ])
 
@@ -434,7 +436,7 @@ def bills(request, abbr):
                     val += ' %'
                 rows[r].append(val)
 
-                # Link to summary/distint views. 
+                # Link to summary/distint views.
                 if 'summary' in spec:
                     try:
                         spec_key = '.'.join(spec['keypath'])
@@ -448,7 +450,7 @@ def bills(request, abbr):
                     else:
                         spec_val = json.dumps(spec_val)
 
-                    params = dict(spec['summary'], session=session, 
+                    params = dict(spec['summary'], session=session,
                                   val=spec_val)
 
                     params = urllib.urlencode(params)
@@ -478,10 +480,9 @@ def bills(request, abbr):
                        tablespecs=tablespecs))
 
 
-def summary_index(request, abbr):
+def summary_index(request, abbr, session):
 
     meta = metadata(abbr)
-    session = request.GET['session']
 
     object_types = 'votes actions versions sponsors documents sources'.split()
 
@@ -503,6 +504,7 @@ def summary_index(request, abbr):
 
         return res
     summary = build_state(abbr)
+
     return render(request, 'billy/summary_index.html', locals())
 
 
@@ -561,7 +563,6 @@ def summary_object_key_vals(request, abbr, urlencode=urllib.urlencode,
     except ValueError:
         pass
 
-    
     spec = {'state': abbr, 'session': session}
     fields = {'_id': 1}
 
@@ -594,7 +595,6 @@ def object_json(request, collection, _id,
     obj_json = json.dumps(obj, cls=JSONDateEncoder, indent=4)
     keys = sorted(obj)
 
-
     def subfunc(m, tmpl='    <a name="%s">%s:</a>'):
         val = m.group(1)
         return tmpl % (val, val)
@@ -608,6 +608,7 @@ def object_json(request, collection, _id,
 
     return render(request, 'billy/object_json.html', locals())
 
+
 def other_actions(request, abbr):
     report = db.reports.find_one({'_id': abbr})
     if not report:
@@ -628,15 +629,17 @@ def unmatched_leg_ids(request, abbr):
     return _csv_response(request, 'leg_ids', ('term', 'chamber', 'name'),
                          sorted(combined_sets), abbr)
 
+
 def uncategorized_subjects(request, abbr):
     report = db.reports.find_one({'_id': abbr})
     if not report:
         raise Http404
     subjects = sorted(report['bills']['uncategorized_subjects'],
-                      key=lambda t: (t[1],t[0]), reverse=True)
+                      key=lambda t: (t[1], t[0]), reverse=True)
     return _csv_response(request, 'uncategorized_subjects', ('subject', '#'),
                          subjects, abbr)
 
+
 def district_stub(request, abbr):
     def keyfunc(x):
         try:
@@ -810,6 +813,23 @@ def legislators(request, abbr):
     })
 
 
+def events(request, abbr):
+    meta = metadata(abbr)
+    level = metadata(abbr)['level']
+
+    events = db.events.find({
+        'level': level,
+        level: abbr.lower()
+    })
+
+    # sort and get rid of old events.
+
+    return render(request, 'billy/events.html', {
+        'events': events,
+        'metadata': meta
+    })
+
+
 def legislator(request, id):
     leg = db.legislators.find_one({'_all_ids': id})
     if not leg:
@@ -956,3 +976,131 @@ def mom_merge(request):
        'remove'          : toRemove,
        'merge_view_info' : mv_info })
 
+
+def newsblogs(request):
+    '''
+    Demo view for news/blog aggregation.
+    ''' 
+    
+    # Pagination insanity.
+    total_count = db.feed_entries.count()
+    limit = int(request.GET.get('limit', 6))
+    page = int(request.GET.get('page', 1))
+    if page < 1:
+        page = 1
+    skip = limit * (page - 1)
+
+    # Whether display is limited to entries tagged with legislator
+    # committee or bill object.
+    entities = request.GET.get('entities', True)
+
+    tab_range = range(1, int(float(total_count) / limit) + 1)
+    tab = skip / limit + 1
+    try:
+        tab_index = tab_range.index(tab)
+    except ValueError:
+        tab_index = 1
+
+    tab_range_len = len(tab_range)
+    pagination_truncated = False
+    if tab_range_len > 8:
+        i = tab_index - 4
+        if i < 0:
+            i = 1
+        j = tab_index
+        k = j + 5
+        previous = tab_range[i: j]
+        current = j
+        next_ = tab_range[j + 1: k]
+        pagination_truncated = True
+    elif tab_range_len == 8:
+        previous = tab_range[:4]
+        next_ = tab_range[4:]
+    else:
+        div, mod = divmod(tab_range_len, 2)
+        if mod == 2:
+            i = tab_range_len / 2
+        else:
+            i = (tab_range_len - 1)/ 2
+        previous = tab_range[:i]
+        next_ = tab_range[i:]
+
+    # Get the data.
+    state = request.GET.get('state')
+
+    if entities is True:
+        spec = {'entity_ids': {'$ne': None}}
+    else:
+        spec = {}
+    if state:
+        spec.update(state=state)
+
+    entries = db.feed_entries.find(spec, skip=skip, limit=limit,
+        sort=[('published_parsed', pymongo.DESCENDING)])
+    _entries = []
+    entity_types = {'L': 'legislators',
+                    'C': 'committees',
+                    'B': 'bills'}
+
+    print tab_range_len, tab, previous, next_, tab_index - 4
+
+    for entry in entries:
+        summary = entry['summary']
+        entity_strings = entry['entity_strings']
+        entity_ids = entry['entity_ids']
+        _entity_strings = []
+        _entity_ids = []
+        _entity_urls = []
+        
+        _done = []
+        if entity_strings:
+            for entity_string, _id in zip(entity_strings, entity_ids):
+                if entity_string in _done:
+                    continue
+                else:
+                    _done.append(entity_string)
+                    _entity_strings.append(entity_string)
+                    _entity_ids.append(_id)
+                entity_type = entity_types[_id[2]]
+                url = urlresolvers.reverse('object_json', args=[entity_type, _id])
+                _entity_urls.append(url)
+                summary = summary.replace(entity_string, 
+                                '<b><a href="%s">%s</a></b>' % (url, entity_string))
+            entity_data = zip(_entity_strings, _entity_ids, _entity_urls)
+            entry['summary'] = summary
+            entry['entity_data'] = entity_data
+        entry['id'] = entry['_id']
+        entry['host'] = urlparse.urlparse(entry['link']).netloc
+
+        # Now hyperlink the inbox data.
+        # if '_inbox_data' in entry:
+        #     inbox_data = entry['_inbox_data']
+        #     for entity in inbox_data['entities']:
+        #         entity_data = entity['entity_data']
+        #         if entity_data['type'] == 'organization':
+        #             ie_url = 'http://influenceexplorer.com/organization/%s/%s'
+        #             ie_url = ie_url % (entity_data['slug'], entity_data['id'])
+        #             print 'found one!'
+        #         else:
+        #             continue
+        #         summary = entry['summary']
+        #         tmpl = '<a href="%s">%s</a>'
+        #         for string in entity['matched_text']:
+        #             summary = summary.replace(string, tmpl % (ie_url, string))
+        #     entry['summary'] = summary
+        
+        _entries.append(entry)
+
+
+
+    return render(request, 'billy/newsblogs.html', {
+        'entries': _entries,
+        'entry_count': entries.count(),
+        'states': db.feed_entries.distinct('state'),
+        'state': state,
+        'tab_range': tab_range,
+        'previous': previous,
+        'next_': next_,
+        'pagination_truncated': pagination_truncated,
+        'page': page,
+        })
